==> haskell-th-extras-0.0.0.8-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-extras
version:              0.0.0.8
visibility:           public
id:                   th-extras-0.0.0.8-LjloIMNzztb7IrKP1v0daC
key:                  th-extras-0.0.0.8-LjloIMNzztb7IrKP1v0daC
license:              LicenseRef-PublicDomain
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/erikd/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  b9e45320413b534ccd9138e6b1620a4c
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-extras
hs-libraries:         HSth-extras-0.0.0.8-LjloIMNzztb7IrKP1v0daC
depends:
    base-4.17.2.1 containers-0.6.7 syb-0.7.2.4-4qGf5rQc5mM7uGogVkfZr0
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-extras-0.0.0.8-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-extras
version:              0.0.0.8
visibility:           public
id:                   th-extras-0.0.0.8-LIqkilkxWI41S8rJQ621cJ
key:                  th-extras-0.0.0.8-LIqkilkxWI41S8rJQ621cJ
license:              LicenseRef-PublicDomain
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/erikd/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  3b15a5e0bcc007bb6d6d6133582ac656
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-extras-0.0.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-extras
hs-libraries:         HSth-extras-0.0.0.8-LIqkilkxWI41S8rJQ621cJ
depends:
    base-4.17.2.1 containers-0.6.7 syb-0.7.2.4-3WceB4hZfgv1oE6BHeIbtE
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
